from http.client import HTTPResponse
from django.shortcuts import redirect
from django.utils import translation
from django.views.generic.base import View
from django.apps import AppConfig
from django.http import Http404, HttpResponse, HttpResponseBadRequest, response
from django.urls import Resolver404
from django.views.generic import TemplateView, ListView
from django.views import View
from django.template import Template, context, loader
from django.http import HttpResponseRedirect
from django.shortcuts import render
from .forms import MainSearchForm
from .models import MainSearchEntry

class IndexView(TemplateView):
    """
    The index page of the gawa app.

    Utilizes a generic view, because I will do so for all views, 
    a regular view function would suffice.
    """

    template_name: str = "start/index.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["MainSearchForm"] = MainSearchForm()
        return context

class ProfessionalView(TemplateView):
    """
    Professional informations that might interest a professional employer
    """
    # TODO
    template_name: str = "start/legalinfo.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["MainSearchForm"] = MainSearchForm()
        return context

class LegalInfoView(TemplateView):
    """
    Legal info that the german authorities want.
    """
    # TODO
    template_name: str = "start/legalinfo.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["MainSearchForm"] = MainSearchForm()
        return context

class ActivateLanguageView(View):
    """
    Set the language to whatever
    """
    language_code = ''
    redirect_to   = ''

    def get(self, request, *args, **kwargs):
        self.redirect_to   = request.META.get('HTTP_REFERER')
        self.language_code = kwargs.get('language_code')
        translation.activate(self.language_code)
        request.session[translation.LANGUAGE_SESSION_KEY] = self.language_code
        return redirect(self.redirect_to)

class MainSearchView(ListView):
    """
    Search for anything.
    """

    model = MainSearchEntry
    object_list = []    # this is only declaration, the view breaks without it.
    template_name: str = "start/search.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["MainSearchForm"] = MainSearchForm()
        return context

    def get(self, request, *args, **kwargs):
        form = MainSearchForm(request.GET)
        if not form.is_valid():
            return render(request, "errors/bad_request.html")

        context = self.get_context_data(**kwargs)
        context["searchstr"] = form.cleaned_data['search']
        #object_list = self.model.objects.filter("something")
        return render(request=request, template_name=self.template_name, context=context)
